<footer class="post-info">
    {% if article.readtime %}
    <span class="label label-success">{{article.readtime.minutes}} min. read</span>
    {% endif %}
    <span class="published">
        <i class="fa fa-calendar"></i>&nbsp;<time datetime="{{ article.date.isoformat() }}"> {{ article.locale_date }}</time>
    </span>
    {% if SHOW_DATE_MODIFIED %}
        {% if article.modified %}
          <span class="label label-default">Modified</span>
            <span class="modified">
                <i class="fa fa-calendar"></i>&nbsp;<time datetime="{{ article.modified.isoformat() }}"> {{ article.locale_modified }}</time>
            </span>
        {% endif %}
    {% endif %}

    {% if SHOW_SERIES %}
        {% if article.series %}
            <span class="label label-default">Series</span>
            Part {{ article.series.index}} of {{ article.series.name }}
        {% endif %}
    {% endif %}

    {% if SHOW_ARTICLE_AUTHOR %}
        {% if article.author %}
            <a href="{{ SITEURL }}/{{ article.author.url }}"><i class="fa fa-user"></i> {{ article.author }}</a>
        {% endif %}
    {% endif %}

    {% if SHOW_ARTICLE_CATEGORY %}
        <span class="label label-default">Category</span>
        <a href="{{ SITEURL }}/{{ article.category.url }}">{{ article.category }}</a>
    {% endif %}

    {% if PDF_PROCESSOR %}
        <span class="label label-default">
            <a href="{{ SITEURL }}/pdf/{{ article.slug }}.pdf">PDF</a>
        </span>
    {% endif %}

    {% include 'includes/taglist.html' %}
    {% import 'includes/translations.html' as translations with context %}
    {{ translations.translations_for(article) }}
</footer><!-- /.post-info -->
