{% if DISPLAY_CATEGORIES_ON_SIDEBAR %}
  {% from 'includes/sidebar/macros.jinja' import title %}

<!-- Sidebar/Categories -->
<li class="list-group-item">
  <h4>{{ title('Categories', DISABLE_SIDEBAR_TITLE_ICONS) }}</h4>
  <ul class="list-group" id="categories">
    {% for cat, null in categories %}
    <li class="list-group-item">
      <a href="{{ SITEURL }}/{{ cat.url }}">
        {%- if not DISABLE_SIDEBAR_TITLE_ICONS -%}
        <i class="fa fa-folder-open fa-lg"></i>
        {%- endif -%}
        {{- cat -}}
      </a>
    </li>
    {% endfor %}
  </ul>
</li>
<!-- End Sidebar/Categories -->
{% endif %}
