{% if DISPLAY_SERIES_ON_SIDEBAR and article and article.series %}
  {% from 'includes/sidebar/macros.jinja' import title %}

<!-- Sidebar/Series -->
<li class="list-group-item">
  <h4>{{ title('Series', DISABLE_SIDEBAR_TITLE_ICONS, icon='tags') }}</h4>
  <ul class="list-group">
    {% if article.series.previous %}
    <li class="list-group-item">
      <h5></i>Previous article</h5>
      <a href="{{ SITEURL }}/{{ article.series.previous.url }}">{{ article.series.previous.title }}</a>
    </li>
    {% endif %}
    {% if article.series.next %}
    <li class="list-group-item">
      <h5>Next article</h5>
      <a href="{{ SITEURL }}/{{ article.series.next.url }}">{{ article.series.next.title }}</a>
    </li>
    {% endif %}
  </ul>
</li>
<!-- End Sidebar/Series -->

{% endif %}
