{% if articles_page and articles_paginator.num_pages > 1 %}
    {% if USE_PAGER %}
        <ul class="pager">
            {% if articles_page.has_previous() %}
                <li class="previous"><a href="{{ SITEURL }}/{{ articles_previous_page.url }}">&larr; Newer</a></li>
            {% else %}
                <li class="previous disabled"><a href="#">&larr; Newer</a></li>
            {% endif %}
            {% if articles_page.has_next() %}
                <li class="next"><a
                        href="{{ SITEURL }}/{{ articles_next_page.url }}">Older &rarr;</a></li>
            {% else %}
                <li class="next disabled"><a href="#">Older &rarr;</a></li>
            {% endif %}
        </ul>
    {% else %}
        <ul class="pagination">
            {% if articles_page.has_previous() %}
                {% set num = articles_page.previous_page_number() %}
                <li class="prev"><a href="{{ SITEURL }}/{{ articles_previous_page.url }}">&laquo;</a>
                </li>
            {% else %}
                <li class="prev disabled"><a href="#">&laquo;</a></li>
            {% endif %}
            {% for num in range( 1, 1 + articles_paginator.num_pages ) %}
                    <li class="{{ 'active' if num == articles_page.number else '' }}"><a
                            href="{{ SITEURL }}/{{ articles_paginator.page(num).url if num > 1 else articles_paginator.page(1).url }}">{{ num }}</a></li>
                {% endfor %}
            {% if articles_page.has_next() %}
                <li class="next"><a
                        href="{{ SITEURL }}/{{ articles_next_page.url }}">&raquo;</a></li>
            {% else %}
                <li class="next disabled"><a href="#">&raquo;</a></li>
            {% endif %}
        </ul>
    {% endif %}
{% endif %}
