{% if article.tags %}
<span class="label label-default">Tags</span>
{% for tag in article.tags %}
	<a href="{{ SITEURL }}/{{ tag.url }}">{{ tag }}</a>
    {% if not loop.last %}
        /
    {% endif %}
{% endfor %}
{% endif %}
