{% if SHOW_SOURCE_ON_SIDEBAR %}
  {% if (article and article.show_source_url) or (page and page.show_source_url) %}

<!-- Show source -->
<li class="list-group-item"><h4><i class="fa fa-tags fa-file-text"></i><span class="icon-label">This Page</span></h4>
  <ul class="list-group">
    <li class="list-group-item">
      {% if article %}
      <a href="{{ SITEURL }}/{{ article.show_source_url }}">Show source</a>
      {% elif page %}
      <a href="{{ SITEURL }}/{{ page.show_source_url }}">Show source</a>
      {% endif %}
    </li>
  </ul>
</li>
<!-- End Show source -->

  {% endif %}
{% endif %}
