<style>
	#banner{
	    background-image:url("{{ SITEURL}}/{{ BANNER }}");
	}
</style>

<div id="banner">
	<div class="container{% if BOOTSTRAP_FLUID %}-fluid{% endif %}">
		<div class="copy">
			<h1>{{ SITENAME }}</h1>
			{% if BANNER_SUBTITLE %}
				<p class="intro">{{ BANNER_SUBTITLE }}</p>
			{% endif %}
		</div>
	</div>
</div>