<footer>
   <div class="container{% if BOOTSTRAP_FLUID %}-fluid{% endif %}">
      <hr>
      <div class="row">
         <div class="col-xs-10 text-muted">
            &copy; {{ CURRENT_YEAR }} {{ AUTHOR }}.
            Site generated using <a href="https://getpelican.com/">Pelican</a>.         </div>
      </div>
   </div>
</footer>
