{% assets filters="rjsmin", output="tipuesearch/tipuesearch.packed.min.js", "tipuesearch/tipuesearch_set.js", "tipuesearch/tipuesearch.js" %}
<script type="text/javascript" src="{{ SITEURL }}/{{ ASSET_URL }}"></script>
{% endassets %}
