<!DOCTYPE html>
{% if USE_OPEN_GRAPH is not defined %}
    {% set USE_OPEN_GRAPH = True %}
{% endif %}
<html lang="{% block html_lang %}{{ DEFAULT_LANG }}{% endblock %}"{% if USE_OPEN_GRAPH %} prefix="og: http://ogp.me/ns# fb: https://www.facebook.com/2008/fbml"{% endif %}>
<head>
    <title>{% block title %}{{ SITENAME }}{% endblock %}</title>
    <!-- Using the latest rendering mode for IE -->
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    {% if 'liquid_tags.notebook' in PLUGINS %}
        {% include 'includes/liquid_tags_nb_header.html' %}
    {% endif %}

    {# Favicons are a touchy subject. For reasoning for the following code, see: http://stackoverflow.com/a/23851464/872397 #}
    {% if FAVICON %}
    <link href="{{ SITEURL }}/{{ FAVICON }}" rel="icon">
    {% endif %}
    {% if FAVICON_IE %}
    <!--[if IE]><link rel="shortcut icon" href="{{ SITEURL }}/{{ FAVICON_IE }}"><![endif]-->
    {% endif %}
    {% if TOUCHICON %}
    <link rel="apple-touch-icon" href="{{ SITEURL }}/{{ TOUCHICON }}">
    {% endif %}

    {% block canonical_rel %}{% endblock %}

    {% block meta %}
        <meta name="author" content="{{ AUTHOR }}" />
    {% endblock %}

    {# Open Graph tags #}
    {% if USE_OPEN_GRAPH %}
    {% block opengraph %}
    <!-- Open Graph tags -->
        {% if OPEN_GRAPH_FB_APP_ID %}
            <meta property="fb:app_id" content="{{ OPEN_GRAPH_FB_APP_ID }}"/>
        {% endif %}
        <meta property="og:site_name" content="{{ SITENAME }}" />
        <meta property="og:type" content="website"/>
        <meta property="og:title" content="{{ SITENAME }}"/>
        <meta property="og:url" content="{{ SITEURL }}"/>
        <meta property="og:description" content="{{ SITENAME }}"/>
        {% if OPEN_GRAPH_IMAGE %}
            <meta property="og:image"
                  content="{{ SITEURL }}/{{ OPEN_GRAPH_IMAGE }}"/>
        {% endif %}
    {% endblock %}
    {% endif %}

    {# Twitter Cards tags #}
    {% include 'includes/twitter_cards.html' %}

    {# Flattr ID for the Flattr browser plug-in #}
    {% if FLATTR_ID %}
        <meta name="flattr:id" content="{{ FLATTR_ID }}">
    {% endif %}

    <!-- Bootstrap -->
    {% if BOOTSTRAP_THEME %}
        <link rel="stylesheet" href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/bootstrap.{{ BOOTSTRAP_THEME }}.min.css" type="text/css"/>
    {% else %}
        <link rel="stylesheet" href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/bootstrap.min.css" type="text/css"/>
    {% endif %}
    <link href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/font-awesome.min.css" rel="stylesheet">

    <link href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/pygments/{{ PYGMENTS_STYLE|default('native') }}.css" rel="stylesheet">
    {% if 'tipue_search' in PLUGINS %}
    <link href="{{ SITEURL}}/{{ THEME_STATIC_DIR }}/tipuesearch/tipuesearch.css" rel="stylesheet">
    {% endif %}
    {% if DOCUTIL_CSS %}
        <link href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/html4css1.css" rel="stylesheet">
    {% endif %}
    {% if TYPOGRIFY %}
        <link href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/typogrify.css" rel="stylesheet">
    {% endif %}
    <link rel="stylesheet" href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/style.css" type="text/css"/>
    {% if CUSTOM_CSS %}
        <link href="{{ SITEURL }}/{{ CUSTOM_CSS }}" rel="stylesheet">
    {% endif %}

    {% if FEED_ALL_ATOM %}
        <link href="{{ SITEURL }}/{{ FEED_ALL_ATOM }}" type="application/atom+xml" rel="alternate"
              title="{{ SITENAME }} ATOM Feed"/>
    {% endif %}

    {% if FEED_ALL_RSS %}
        <link href="{{ SITEURL }}/{{ FEED_ALL_RSS }}" type="application/rss+xml" rel="alternate"
              title="{{ SITENAME }} RSS Feed"/>
    {% endif %}

    {%- if tag and TAG_FEED_ATOM %}
        {%- if '%s' not in TAG_FEED_ATOM %}
            {%- set tag_feed_atom = TAG_FEED_ATOM.format(slug=tag.slug) %}
        {%- else %}
            {%- set tag_feed_atom = TAG_FEED_ATOM.format(tag.slug) %}
        {%- endif %}
        <link href="{{ SITEURL }}/{{ tag_feed_atom }}" type="application/atom+xml" rel="alternate"
              title="{{ SITENAME }} {{ tag }} ATOM Feed"/>
    {%- endif %}
    {%- if category and CATEGORY_FEED_ATOM %}
        {%- if '%s' not in CATEGORY_FEED_ATOM %}
            {%- set category_feed_atom = CATEGORY_FEED_ATOM.format(slug=category.slug) %}
        {%- else %}
            {%- set category_feed_atom = CATEGORY_FEED_ATOM.format(category.slug) %}
        {%- endif %}
        <link href="{{ SITEURL }}/{{ category_feed_atom }}" type="application/atom+xml" rel="alternate"
              title="{{ SITENAME }} {{ category }} ATOM Feed"/>
    {%- endif %}

    {% include 'includes/ga.html' %}

</head>
<body>

<div class="navbar {% if BOOTSTRAP_NAVBAR_INVERSE %}navbar-inverse{% else %}navbar-default{% endif %} navbar-fixed-top" role="navigation">
    <div class="container{% if BOOTSTRAP_FLUID %}-fluid{% endif %}">
        <div class="navbar-header">
            <a href="{{ SITEURL }}/" class="navbar-brand">
                {% if SITELOGO %}<img class="img-responsive pull-left gap-right" src="{{ SITEURL }}/{{ SITELOGO }}" width="{{ SITELOGO_SIZE }}"/> {% endif %}
                {% if not HIDE_SITENAME %}{{ SITENAME }}{% endif %}
            </a>
        </div>
        <div class="collapse navbar-collapse navbar-ex1-collapse">
            <!-- <ul class="nav navbar-nav">
                <li><a href="#">Title bar nav</a></li>
            </ul> -->
            <ul class="nav navbar-nav navbar-right">
            {% if 'tipue_search' in PLUGINS %}
              <li><span>
                <form class="navbar-search" action="{{ SEARCH_URL | default('/search.html') }}">
                  <input type="text" class="search-query" placeholder="Search" name="q" id="tipue_search_input" required>
                </form></span>
              </li>
            {% endif %}
            {% if ARCHIVES_SAVE_AS %}
              <li><a href="{{ SITEURL }}/{{ ARCHIVES_URL | default('archives.html') }}"><i class="fa fa-th-list"></i><span class="icon-label">Archives</span></a></li>
            {% endif %}
            </ul>
        </div>
        <!-- /.navbar-collapse -->
    </div>
</div> <!-- /.navbar -->

<!-- Banner -->
{% if BANNER and BANNER_ALL_PAGES %}
    {% include 'includes/banner.html' %}
{% elif BANNER and not BANNER_ALL_PAGES %}
    {% block banner %}{% endblock %}
{% endif %}
<!-- End Banner -->

<!-- Content Container -->
{% if PADDED_SINGLE_COLUMN_STYLE %}
    {% set content_class='col-md-8 col-md-offset-2' %}
{% elif not HIDE_SIDEBAR or ABOUT_ME or AVATAR %}
    {% set content_class='col-sm-9' + (' col-sm-push-3' if SIDEBAR_ON_LEFT else '') %}
    {% set sidebar_class='col-sm-3' + (' col-sm-pull-9' if SIDEBAR_ON_LEFT else '') %}
{% else %}
    {% set content_class='col-lg-12' %}
{% endif %}
<div class="container{% if BOOTSTRAP_FLUID %}-fluid{% endif %}">
    <div class="row">
        <div class="{{ content_class }}">
            {% block breadcrumbs %}{% endblock %}
            {% block content %}{% endblock %}
        </div>
        {% if sidebar_class %}
        <div class="{{ sidebar_class }}" id="sidebar">
            <aside>
                {% if ABOUT_ME or AVATAR %}
                    {% include 'includes/aboutme.html' %}
                {% endif %}
                {% if not HIDE_SIDEBAR %}
                    {% include 'includes/sidebar.html' %}
                {% endif %}
            </aside>
        </div>
        {% endif %}
    </div>
</div>
<!-- End Content Container -->

{% include 'includes/footer.html' %}

<script src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/js/jquery.min.js"></script>

<!-- Include all compiled plugins (below), or include individual files as needed -->
<script src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/js/bootstrap.min.js"></script>

<!-- Enable responsive features in IE8 with Respond.js (https://github.com/scottjehl/Respond) -->
<script src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/js/respond.min.js"></script>

{% if CUSTOM_JS %}
    <script src="{{ SITEURL }}/{{ CUSTOM_JS }}"></script>
{% endif %}

{% if BANNER %}
    <script src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/js/bodypadding.js"></script>
{% endif %}
{% include 'includes/piwik.html' %}

{% if 'liquid_tags.notebook' in PLUGINS %}
    {% include 'includes/liquid_tags_nb_footer.html' %}
{% endif %}

{% block scripts %}{% endblock %}
</body>
</html>
