{% extends "base.html" %}
{% block content %}
    <header class="page-header">
        <h1>{% block heading %}{% endblock %}</h1>
    </header>
    {% if articles %}
        {% for article in (articles_page.object_list if articles_page else articles) %}
            <article>
                <h4><a href="{{ SITEURL }}/{{ article.url }}">{{ article.title }}</a></h4>
                {% if DISPLAY_ARTICLE_INFO_ON_INDEX %}
                    <div class="well well-sm">
                        {% include "includes/article_info.html" %}
                    </div>
                {% endif %}
                <div class="summary">{{ article.summary }}
                </div>
            </article>
            <hr/>
        {% endfor %}
    {% endif %}

    {% include 'includes/pagination.html' %}
{% endblock content %}
