<!-- Sidebar -->
<section class="well well-sm" style="margin-top: 4em;">
  <ul class="list-group list-group-flush">
    {% include 'includes/sidebar/optional_top.html' ignore missing %}
    {% include 'includes/sidebar/navigation.html' %}
    {% include 'includes/sidebar/social.html' %}
    {% include 'includes/sidebar/recent_posts.html' %}
    {% include 'includes/sidebar/categories.html' %}
    {% include 'includes/sidebar/tag_cloud.html' %}
    {% include 'includes/sidebar/show_source.html' %}
    {% include 'includes/sidebar/series.html' %}
    {% include 'includes/sidebar/links.html' %}
    {% include 'includes/sidebar/images.html' %}
    {% include 'includes/sidebar/archive.html' %}
    {% include 'includes/sidebar/optional_bottom.html' ignore missing %}
  </ul>
</section>
<!-- End Sidebar -->
